@@ -28,7 +28,7 @@
 #include <apt-pkg/configuration.h>
 
 // Own includes
-#include "workerdbus.h" // OrgKubuntuQaptworker2Interface
+#include "dbusinterfaces_p.h"
 
 namespace QApt {
 
@@ -36,8 +36,8 @@ class SourcesListPrivate
 {
 public:
     SourcesListPrivate(const QStringList &sourcesList = QStringList())
-    : sourceFiles(QStringList())
-    , list(QHash<QString,QApt::SourceEntryList>())
+        : sourceFiles(QStringList())
+        , list(QHash<QString,QApt::SourceEntryList>())
     {
         if ( sourcesList.isEmpty() ) {
             setDefaultSourcesFiles();
@@ -49,9 +49,9 @@ public:
 
     // File list
     QStringList sourceFiles;
-    
+
     // DBus
-    OrgKubuntuQaptworker2Interface *worker;
+    WorkerInterface *worker;
 
     // Data
     QHash< QString, QApt::SourceEntryList > list;
@@ -59,36 +59,32 @@ public:
     void setDefaultSourcesFiles();
     void reload();
     void load(const QString &filePath);
-    
+
     void addSourcesFile(const QString &filePath);
     void addSourcesFileList(const QStringList &filePathList);
 };
 
-void SourcesListPrivate::addSourcesFile ( const QString& filePath )
+void SourcesListPrivate::addSourcesFile(const QString& filePath)
 {
     // Just some basic deduping
     if (sourceFiles.contains(filePath)) {
         return;
     }
-    
+
     sourceFiles.append(filePath);
-    
-    return;
 }
 
-void SourcesListPrivate::addSourcesFileList ( const QStringList& filePathList )
+void SourcesListPrivate::addSourcesFileList(const QStringList& filePathList)
 {
     for (const QString &filePathEntry : filePathList) {
         addSourcesFile(filePathEntry);
     }
-    
-    return;
 }
 
 void SourcesListPrivate::setDefaultSourcesFiles()
 {
     addSourcesFile(QString::fromStdString(_config->FindFile("Dir::Etc::sourcelist")));
-    
+
     // Go through the parts dir and append those
     QDir partsDir(QString::fromStdString(_config->FindFile("Dir::Etc::sourceparts")));
     for (const QString& file : partsDir.entryList(QStringList() << "*.list")) {
@@ -101,9 +97,9 @@ void SourcesListPrivate::setDefaultSourcesFiles()
 void SourcesListPrivate::reload()
 {
     list.clear();
-    
-    for (const QString& file : sourceFiles) {
-        if ( ! file.isNull() && ! file.isEmpty() ) {
+
+    for (const QString &file : sourceFiles) {
+        if (!file.isNull() && !file.isEmpty() ) {
             load(file);
         }
     }
@@ -112,12 +108,12 @@ void SourcesListPrivate::reload()
 void SourcesListPrivate::load(const QString &filePath)
 {
     QFile file(filePath);
-    
+
     if (!file.open(QFile::Text | QIODevice::ReadOnly)) {
         qWarning() << "Unable to open the file " << filePath << " as read-only text: " << file.errorString();
         return;
     }
-    
+
     // Make a source entry for each line in the file
     while (!file.atEnd()) {
         QString line = file.readLine();
@@ -131,7 +127,7 @@ SourcesList::SourcesList(QObject *parent)
 {
     Q_D(SourcesList);
 
-    d->worker = new OrgKubuntuQaptworker2Interface(QLatin1String("org.kubuntu.qaptworker2"),
+    d->worker = new WorkerInterface(QLatin1String(s_workerReverseDomainName),
                                                   QLatin1String("/"), QDBusConnection::systemBus(),
                                                   this);
 }
@@ -142,7 +138,7 @@ SourcesList::SourcesList(QObject *parent, const QStringList &sourcesFileList)
 {
     Q_D(SourcesList);
 
-    d->worker = new OrgKubuntuQaptworker2Interface(QLatin1String("org.kubuntu.qaptworker2"),
+    d->worker = new WorkerInterface(QLatin1String(s_workerReverseDomainName),
                                                   QLatin1String("/"), QDBusConnection::systemBus(),
                                                   this);
 }
@@ -157,11 +153,11 @@ SourceEntryList SourcesList::entries() const
     Q_D(const SourcesList);
 
     SourceEntryList to_return;
-    
+
     for (const SourceEntryList &oneList : d->list.values()) {
         to_return.append(oneList);
     }
-    
+
     return to_return;
 }
 
@@ -182,16 +178,16 @@ void SourcesList::reload()
 void SourcesList::addEntry(const SourceEntry &entry)
 {
     Q_D(SourcesList);
-    
+
     QString entryForFile = entry.file();
-    
+
     // Default to the zeroth file if no file is specified.
     if (entryForFile.isEmpty()) {
         entryForFile = sourceFiles().at(0);
     }
 
     // TODO: More sophisticated dupe checking, e.g. in the case of adding new components
-    for (const SourceEntry &item : this->entries(entryForFile)) {
+    for (const SourceEntry &item : entries(entryForFile)) {
         if (entry == item) {
             return;
         }
@@ -210,22 +206,22 @@ void SourcesList::removeEntry(const SourceEntry &entry)
         d->list[entryForFile].removeAll(entry);
         return;
     }
-    
+
     for (QString &sourcesFile : sourceFiles()) {
         d->list[sourcesFile].removeAll(entry);
     }
-    
+
     return;
 }
 
-bool SourcesList::containsEntry(const SourceEntry& entry, const QString& sourceFile)
+bool SourcesList::containsEntry(const SourceEntry& entry, const QString &sourceFile)
 {
     // Don't optimize for the file if we don't have a usable file
     if (sourceFile.isEmpty()) {
-        return this->entries().contains(entry);
+        return entries().contains(entry);
     }
-    
-    return this->entries(sourceFile).contains(entry);
+
+    return entries(sourceFile).contains(entry);
 }
 
 QStringList SourcesList::sourceFiles()
@@ -236,35 +232,35 @@ QStringList SourcesList::sourceFiles()
 }
 
 QString SourcesList::dataForSourceFile(const QString& sourceFile)
-{    
+{
     QString to_return;
-    
-    for (const SourceEntry &listEntry : this->entries(sourceFile)) {
+
+    for (const SourceEntry &listEntry : entries(sourceFile)) {
         to_return.append(listEntry.toString() + '\n');
     }
-    
+
     if (to_return.isEmpty()) {
         to_return.append(QString("## See sources.list(5) for more information, especially\n"
                                  "# Remember that you can only use http, ftp or file URIs.\n"
                                  "# CDROMs are managed through the apt-cdrom tool.\n"));
     }
-    
+
     return to_return;
 }
 
 QString SourcesList::toString() const
 {
     Q_D(const SourcesList);
-    
+
     QString toReturn;
-    
+
     for (const QString &sourceFile : d->sourceFiles) {
-        toReturn += sourceFile + "\n";
-        for (const QApt::SourceEntry &sourceEntry : this->entries(sourceFile)) {
-            toReturn += sourceEntry.toString() + "\n";
+        toReturn += sourceFile + '\n';
+        for (const QApt::SourceEntry &sourceEntry : entries(sourceFile)) {
+            toReturn += sourceEntry.toString() + '\n';
         }
     }
-    
+
     return toReturn;
 }
 
@@ -272,14 +268,12 @@ void SourcesList::save()
 {
     Q_D(SourcesList);
 
-    for (const QString &sourceFile : this->sourceFiles()) {
-        qDebug() << "Writing file " << sourceFile << " with: " << this->dataForSourceFile(sourceFile);
-        if (! d->worker->writeFileToDisk(this->dataForSourceFile(sourceFile), sourceFile)) {
+    for (const QString &sourceFile : sourceFiles()) {
+        qDebug() << "Writing file " << sourceFile << " with: " << dataForSourceFile(sourceFile);
+        if (! d->worker->writeFileToDisk(dataForSourceFile(sourceFile), sourceFile)) {
             qWarning() << "Failed to write the file to disk (dbus call failed)!";
         }
     }
-
-    return;
 }
 
 }
